Module: Aws::ResourceGroupsTaggingAPI::Errors
- Extended by:
- Errors::DynamicErrors
- Defined in:
- lib/aws-sdk-resourcegroupstaggingapi/errors.rb,
sig/errors.rbs
Overview
When ResourceGroupsTaggingAPI returns an error response, the Ruby SDK constructs and raises an error. These errors all extend Aws::ResourceGroupsTaggingAPI::Errors::ServiceError < Errors::ServiceError
You can rescue all ResourceGroupsTaggingAPI errors using ServiceError:
begin
# do stuff
rescue Aws::ResourceGroupsTaggingAPI::Errors::ServiceError
# rescues all ResourceGroupsTaggingAPI API errors
end
Request Context
ServiceError objects have a #context method that returns information about the request that generated the error. See Seahorse::Client::RequestContext for more information.
Error Classes
- ConcurrentModificationException
- ConstraintViolationException
- InternalServiceException
- InvalidParameterException
- PaginationTokenExpiredException
- ThrottledException
Additionally, error classes are dynamically generated for service errors based on the error code if they are not defined above.
Defined Under Namespace
Classes: ConcurrentModificationException, ConstraintViolationException, InternalServiceException, InvalidParameterException, PaginationTokenExpiredException, ServiceError, ThrottledException